@@ -2,7 +2,7 @@ package WebService::MinFraud::Validator;
 
 use Moo;
 
-our $VERSION = '0.004000';
+our $VERSION = '1.000000';
 
 use Data::Delete 0.05;
 use Data::Rx;
@@ -195,11 +195,13 @@ sub _build_request_schema_definition {
                                 'cielo',
                                 'collector',
                                 'compropago',
+                                'concept_payments',
                                 'conekta',
                                 'cuentadigital',
                                 'dalpay',
                                 'dibs',
                                 'digital_river',
+                                'ecomm365',
                                 'elavon',
                                 'epay',
                                 'eprocessing_network',
@@ -219,7 +221,9 @@ sub _build_request_schema_definition {
                                 'nmi',
                                 'openpaymx',
                                 'optimal_payments',
+                                'orangepay',
                                 'other',
+                                'pacnet_services',
                                 'payfast',
                                 'paygate',
                                 'payone',
@@ -344,7 +348,7 @@ WebService::MinFraud::Validator - Validation for the minFraud requests
 
 =head1 VERSION
 
-version 0.004000
+version 1.000000
 
 =head1 SYNOPSIS
 
